CREATE TABLE `project` (
  `id` BIGINT(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `region_id` BIGINT(20) DEFAULT NULL COMMENT '地区ID',
  `data_year` INT(11) DEFAULT NULL COMMENT '年份',
  `project_name` VARCHAR(225) DEFAULT NULL COMMENT '项目名称',
  `degree` VARCHAR(11) DEFAULT NULL COMMENT '项目等级',
  `total` DECIMAL(18,5) DEFAULT NULL COMMENT '投资总额',
  `growth` DECIMAL(18,5) DEFAULT NULL COMMENT '同比数据值',
  `photo` VARCHAR(255) DEFAULT NULL COMMENT '照片',
  `icon` VARCHAR(255) DEFAULT NULL COMMENT '图标',
  `address` VARCHAR(11) DEFAULT NULL COMMENT '事故地址',
  `latitude` VARCHAR(255) DEFAULT NULL COMMENT '纬度',
  `longitude` VARCHAR(255) DEFAULT NULL COMMENT '经度',
  `created_at` DATETIME DEFAULT NULL COMMENT '创建时间',
  `created_by` BIGINT(20) DEFAULT NULL COMMENT '创建人',
  `deleted_at` DATETIME DEFAULT NULL COMMENT '删除时间',
  `deleted_by` BIGINT(20) DEFAULT NULL COMMENT '删除人',
  PRIMARY KEY (`id`)
) ENGINE=INNODB  DEFAULT CHARSET=utf8 COMMENT='项目分布';

CREATE TABLE `project_analyse` (
  `id` BIGINT(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `region_id` BIGINT(20) DEFAULT NULL COMMENT '地区ID',
  `data_year` INT(11) DEFAULT NULL COMMENT '年份',
  `degree` VARCHAR(255) DEFAULT NULL COMMENT '项目阶段',
  `total` DECIMAL(18,5) DEFAULT NULL COMMENT '项目总额',
  `growth` DECIMAL(18,5) DEFAULT NULL COMMENT '同比值',
  `photo` VARCHAR(255) DEFAULT NULL COMMENT '照片',
  `icon` VARCHAR(255) DEFAULT NULL COMMENT '图标',
  `latitude` VARCHAR(255) DEFAULT NULL COMMENT '纬度',
  `longitude` VARCHAR(255) DEFAULT NULL COMMENT '经度',
  `created_at` DATETIME DEFAULT NULL COMMENT '创建时间',
  `created_by` BIGINT(20) DEFAULT NULL COMMENT '创建人',
  `deleted_at` DATETIME DEFAULT NULL COMMENT '删除时间',
  `deleted_by` BIGINT(20) DEFAULT NULL COMMENT '删除人',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8 COMMENT='项目进展分析';

CREATE TABLE `project_statistics` (
  `id` BIGINT(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `region_id` BIGINT(20) DEFAULT NULL COMMENT '地区ID',
  `data_year` INT(11) DEFAULT NULL COMMENT '年份',
  `type` VARCHAR(255) DEFAULT NULL COMMENT '项目类型',
  `total` DECIMAL(11,8) DEFAULT NULL COMMENT '项目总额',
  `number` INT(11) DEFAULT NULL COMMENT '项目个数',
  `growth` DECIMAL(18,5) DEFAULT NULL COMMENT '同比值',
  `ring` DECIMAL(18,5) DEFAULT NULL COMMENT '环比值',
  `photo` VARCHAR(255) DEFAULT NULL COMMENT '照片',
  `icon` VARCHAR(255) DEFAULT NULL COMMENT '图标',
  `latitude` VARCHAR(255) DEFAULT NULL COMMENT '纬度',
  `longitude` VARCHAR(255) DEFAULT NULL COMMENT '经度',
  `created_at` DATETIME DEFAULT NULL COMMENT '创建时间',
  `created_by` BIGINT(20) DEFAULT NULL COMMENT '创建人',
  `deleted_at` DATETIME DEFAULT NULL COMMENT '删除时间',
  `deleted_by` BIGINT(20) DEFAULT NULL COMMENT '删除人',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8 COMMENT='投资项目统计';

CREATE TABLE `project_type` (
  `id` BIGINT(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `region_id` BIGINT(20) DEFAULT NULL COMMENT '地区ID',
  `data_year` INT(11) DEFAULT NULL COMMENT '年份',
  `type` VARCHAR(255) DEFAULT NULL COMMENT '项目类型',
  `total` DECIMAL(18,5) DEFAULT NULL COMMENT '项目总额',
  `number` INT(11) DEFAULT NULL COMMENT '项目个数',
  `growth` DECIMAL(18,5) DEFAULT NULL COMMENT '同比值',
  `photo` VARCHAR(255) DEFAULT NULL COMMENT '照片',
  `icon` VARCHAR(255) DEFAULT NULL COMMENT '图标',
  `latitude` VARCHAR(255) DEFAULT NULL COMMENT '纬度',
  `longitude` VARCHAR(255) DEFAULT NULL COMMENT '经度',
  `created_at` DATETIME DEFAULT NULL COMMENT '创建时间',
  `created_by` BIGINT(20) DEFAULT NULL COMMENT '创建人',
  `deleted_at` DATETIME DEFAULT NULL COMMENT '删除时间',
  `deleted_by` BIGINT(20) DEFAULT NULL COMMENT '删除人',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8 COMMENT='项目类型';

CREATE TABLE `project_accident_analyse` (
  `id` BIGINT(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `region_id` BIGINT(20) DEFAULT NULL COMMENT '地区ID',
  `data_year` INT(11) DEFAULT NULL COMMENT '年份',
  `degree` VARCHAR(255) DEFAULT NULL COMMENT '项目等级',
  `type` VARCHAR(255) DEFAULT NULL COMMENT '项目类型',
  `total` DECIMAL(11) DEFAULT NULL COMMENT '项目总额',
  `number` INT(11) DEFAULT NULL COMMENT '项目事故数',
  `growth` DECIMAL(18,5) DEFAULT NULL COMMENT '同比值',
  `ring` DECIMAL(18,5) DEFAULT NULL COMMENT '环比值',
  `photo` VARCHAR(255) DEFAULT NULL COMMENT '照片',
  `icon` VARCHAR(255) DEFAULT NULL COMMENT '图标',
  `latitude` VARCHAR(255) DEFAULT NULL COMMENT '纬度',
  `longitude` VARCHAR(255) DEFAULT NULL COMMENT '经度',
  `created_at` DATETIME DEFAULT NULL COMMENT '创建时间',
  `created_by` BIGINT(20) DEFAULT NULL COMMENT '创建人',
  `deleted_at` DATETIME DEFAULT NULL COMMENT '删除时间',
  `deleted_by` BIGINT(20) DEFAULT NULL COMMENT '删除人',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8 COMMENT='项目事故分析';

Drop table if EXISTS police_manning;
CREATE TABLE `police_manning` (
  `id` BIGINT(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `region_id` BIGINT(20) DEFAULT NULL COMMENT '地区ID',
  `data_year` INT(11) DEFAULT NULL COMMENT '年份',
  `type` VARCHAR(225) DEFAULT NULL COMMENT '人员类型',
  `number` INT(11) DEFAULT NULL COMMENT '数据值',
  `growth` DECIMAL(18,5) DEFAULT NULL COMMENT '同比值',
  `photo` VARCHAR(255) DEFAULT NULL COMMENT '照片',
  `icon` VARCHAR(255) DEFAULT NULL COMMENT '图标',
  `latitude` VARCHAR(255) DEFAULT NULL COMMENT '纬度',
  `longitude` VARCHAR(255) DEFAULT NULL COMMENT '经度',
  `created_at` DATETIME DEFAULT NULL COMMENT '创建时间',
  `created_by` BIGINT(20) DEFAULT NULL COMMENT '创建人',
  `deleted_at` DATETIME DEFAULT NULL COMMENT '删除时间',
  `deleted_by` BIGINT(20) DEFAULT NULL COMMENT '删除人',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8 COMMENT='警员配置数'
